@@ -14,19 +14,25 @@ class YoloxDetector:
         model_path: str,
         config_path: str,
         device: str = "cpu",
+        hf_model: bool = False,
     ):
 
         self.device = device
-        self.model_path = attempt_download_from_hub(model_path)
         self.config_path = config_path
         self.classes = COCO_CLASSES
-        self.conf = 0.35
+        self.conf = 0.3
         self.iou = 0.45
         self.show = False  
         self.save = True
         
         if self.save:
             self.save_path = 'output/result.jpg'
+            
+        if hf_model:
+            self.model_path = attempt_download_from_hub(model_path)
+        
+        else:
+            self.model_path = model_path
         
     
         self.load_model()
@@ -44,9 +50,8 @@ class YoloxDetector:
         self.model = model
 
 
-    def predict(self, img_path, image_size): 
-        image = cv2.imread(img_path)   
-         
+    def predict(self, image, image_size):    
+        image = cv2.imread(image)    
         if image_size is not None:
             ratio = min(image_size / image.shape[0], image_size / image.shape[1])
             img, _ = preproc(image, input_size=(image_size, image_size))
@@ -58,8 +63,12 @@ class YoloxDetector:
             img = torch.from_numpy(img).to(self.device).unsqueeze(0).float()
 
         prediction_result = self.model(img)
-        original_predictions = postprocess(prediction=prediction_result,num_classes= len(COCO_CLASSES),conf_thre=self.conf,nms_thre=self.iou)[0]
-
+        original_predictions = postprocess(
+            prediction=prediction_result,
+            num_classes= len(COCO_CLASSES),
+            conf_thre=self.conf,
+            nms_thre=self.iou)[0]
+        
         output = original_predictions.cpu()
         bboxes = output[:, 0:4]
         bboxes /= ratio
@@ -88,13 +97,15 @@ class YoloxDetector:
         else:
             return vis_res
 
+
 if __name__ == "__main__":
-    yolox = YoloxDetector(
-        model_path="kadirnar/yolox_s-v0.1.1",
-        config_path="configs.yolox_s",
-        device="cpu",
+    model = YoloxDetector(
+        model_path = "kadirnar/yolox_s-v0.1.1",
+        config_path = "configs.yolox_s",
+        device = "cuda:0",
+        hf_model=True,
     )
-    yolox.predict(
-        img_path="data/images/dog.jpg",
-        image_size=640,
-    )
\ No newline at end of file
+
+    image = "data/images/dog.jpg"
+    
+    model.predict(image, 640)
\ No newline at end of file
